package wing.fx.dialog;

import javafx.application.Application;
import javafx.scene.Node;
import javafx.scene.control.Button;
import javafx.stage.Stage;

import java.util.Arrays;
import java.util.Optional;

/**
 * @author Mikael Grev, MiG InfoCom AB
 *         Date: 14-06-22
 *         Time: 23:21
 */
public class DialogTestApp extends Application
{
	public void start(Stage stage) throws Exception
	{
		// Simplest possible Ok/Cancel

		Optional<ButtonType> pressed1 = Dialog.createMessage("Return to the moon?").show(stage);
		pressed1.ifPresent(s -> System.out.println("You selected: " + s));

		// Normal Yes/no question

		Optional<ButtonType> pressed2 = Dialog.createMessage("Are you a Festis?")
			.buttons(ButtonType.YES, ButtonType.NO)
			.masthead("Important Question Below")
			.show();
		pressed2.ifPresent(s -> System.out.println("You selected: " + s));

		// Normal single line input

		Optional<String> festisName = Dialog.createSingleLineInput("Your Festis name please:").show();
		festisName.ifPresent(s -> System.out.println("You selected: " + s));

		// Simple choice selection

		Optional<String> type = Dialog.createSingleChoice("Which kind of festis are you?", Arrays.asList("Blackberry", "Strawberry", "Raspberry"))
			.show();
		type.ifPresent(s -> System.out.println("You selected: " + s));

		// Custom text on buttons for standard button types

		Optional<ButtonType> pressed3 = Dialog.createMessage("Delete All Files?")
			.masthead("This is not a joke", getGfxNode())
			.addButton(new Button("No, don't delete"), ButtonType.NO)
			.addButton(new Button("Yes, delete files"), ButtonType.YES)
			.show(stage);
		pressed3.ifPresent(s -> System.out.println("You selected: " + s));

		// Apply support

		Optional<String> name = Dialog.createSingleLineInput("What is your name", s -> !s.trim().isEmpty())
			.masthead("This is a simple query", getGfxNode())
			.applyTo(s -> System.out.println("Your name is: " + s))
			.buttons(ButtonType.OK, ButtonType.CANCEL, ButtonType.APPLY)
			.show();
		name.ifPresent(s -> System.out.println("You selected: " + s));

		// Custom buttons with no sane normal button type

		Dialog<ButtonType> dialog = Dialog.createMessage("What will you do today?")
			.addButton(new Button("Buy a Tesla Model S"), ButtonType.CUSTOM_CLOSE_APPLY)
			.addButton(new Button("Buy a Tesla Model X"), ButtonType.CUSTOM_CLOSE_APPLY);

		dialog.show(stage);
		System.out.println("You pressed button: " + dialog.getPressedButton());
		System.out.println("You pressed button type: " + dialog.getPressedButtonType());
		System.out.println("Result: " + dialog.getResult());
	}

	public static Node getGfxNode()
	{
		return null;
	}

	public static void main(String[] args)
	{
		launch(args);
	}

}
