package wing.fx.dialog;

import javafx.collections.ObservableList;
import javafx.geometry.Pos;
import javafx.scene.Node;
import javafx.scene.control.ChoiceBox;
import javafx.scene.control.Label;
import javafx.scene.layout.HBox;
import javafx.util.StringConverter;
import org.tbee.javafx.scene.layout.MigPane;

import java.util.Optional;
import java.util.function.Function;

/**
 * @author Mikael Grev, MiG InfoCom AB
 *         Date: 14-06-22
 *         Time: 21:08
 */
public class SingleChoice<V> extends MigPane implements DialogContent<V>
{
	private final ChoiceBox<V> choiceBox;

	/**
	 * @param items null items are allowed.
	 * @param select If value is null nothing is selected. If empty first in items is selected.
	 * @param toString Can be null in which case String.valueOf(item) is used.
	 */
	public SingleChoice(String label, ObservableList<V> items, Optional<V> select, Function<V, String> toString)
	{
		if (label != null)
			add(new Label(label));

		choiceBox = new ChoiceBox<>(items);

		select.ifPresent(value -> choiceBox.getSelectionModel().select(value));

		if (toString != null) {
			choiceBox.setConverter(new StringConverter<V>() {
				public String toString(V item)
				{
					return toString.apply(item);
				}
				public V fromString(String string)
				{
					throw new UnsupportedOperationException();
				}
			});
		}

		add(choiceBox);
	}

	public Optional<V> getResult(ButtonType pressed)
	{
		return pressed.isApply() ? Optional.ofNullable(choiceBox.getSelectionModel().getSelectedItem()) : Optional.empty();
	}

	public Node getContentNode()
	{
		return this;
	}
}
