package wing.fx.dialog;

import javafx.scene.Node;
import javafx.scene.control.Label;
import javafx.scene.control.TextField;
import org.tbee.javafx.scene.layout.MigPane;

import java.util.Optional;
import java.util.function.Predicate;

/**
 * @author Mikael Grev, MiG InfoCom AB
 *         Date: 14-06-22
 *         Time: 20:40
 */
public class SingleLineInput extends MigPane implements DialogContent<String>
{
	private final TextField textField;
	private final Predicate<String> validator;

	private Dialog<String> dialog;

	public SingleLineInput(String labelText, String defaultText, String promptText, int columnCount, Predicate<String> validator)
	{
		this.validator = validator;

		if (labelText != null)
			add(new Label(labelText));

		textField = new TextField();

		if (defaultText != null)
			textField.setText(defaultText);

		if (columnCount >= 0)
			textField.setPrefColumnCount(columnCount);

		if (promptText != null)
			textField.setPromptText(promptText);

		if (validator != null)
			textField.textProperty().addListener((observable, oldText, newText) -> enableDisableApplyButtons(validator, newText));

		add(textField);
	}

	private void enableDisableApplyButtons(Predicate<String> validator, String text)
	{
		boolean disable = !validator.test(text);
		dialog.getApplyButtons().stream().forEach(button -> button.setDisable(disable));
	}

	public void setDialog(Dialog<String> dialog)
	{
		this.dialog = dialog;
		if (validator != null)
			enableDisableApplyButtons(validator, textField.getText());
	}

	public Optional<String> getResult(ButtonType pressed)
	{
		return pressed.isApply() ? Optional.of(textField.getText()) : Optional.empty();
	}

	public Node getContentNode()
	{
		return this;
	}
}
